pub struct ConnectionSelectionManager { /* private fields */ }Expand description
Manages the active connection selection futures, allowing for selective cancellation.
Implementations
Sourceimpl ConnectionSelectionManager
impl ConnectionSelectionManager
pub fn new(requester: ConnectionSelectionRequester) -> Self
Sourcepub fn spawn(
&mut self,
selection_id: SelectionIdentifier,
selection_future: LocalBoxFuture<'static, Result<ConnectionSelectionResponse, Error>>,
)
pub fn spawn( &mut self, selection_id: SelectionIdentifier, selection_future: LocalBoxFuture<'static, Result<ConnectionSelectionResponse, Error>>, )
Spawns a new connection selection future with an associated SelectionIdentifier. Wraps the future in a cancellation logic.
Sourcepub fn cancel(&mut self, selection_id: &SelectionIdentifier)
pub fn cancel(&mut self, selection_id: &SelectionIdentifier)
Cancels the future associated with the given selection_id.
Sourcepub fn cancel_all(&mut self)
pub fn cancel_all(&mut self)
Cancels all active connection selections.
Sourcepub fn active_selections(&self) -> Vec<SelectionIdentifier>
pub fn active_selections(&self) -> Vec<SelectionIdentifier>
Returns a list of SelectionIdentifiers for connection selections currently being processed.
pub fn initiate_automatic_connection_selection(&mut self)
pub fn initiate_connection_selection_for_connect_request( &mut self, request: ConnectAttemptRequest, )