ClientApi

Trait ClientApi 

pub trait ClientApi {
    // Required methods
    fn connect(&mut self, selection: ConnectSelection) -> Result<(), Error>;
    fn disconnect(
        &mut self,
        reason: DisconnectReason,
        responder: Sender<()>,
    ) -> Result<(), Error>;
    fn is_alive(&self) -> bool;
}

Required Methods

fn connect(&mut self, selection: ConnectSelection) -> Result<(), Error>

fn disconnect( &mut self, reason: DisconnectReason, responder: Sender<()>, ) -> Result<(), Error>

fn is_alive(&self) -> bool

Queries the liveness of the channel used to control the client state machine. If the channel is not alive, this indicates that the client state machine has exited.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors