HistoricalList

Struct HistoricalList 

pub struct HistoricalList<T, const N: usize>(pub VecDeque<T>)
where
    T: Timestamped;
Struct for list that stores historical data in a VecDeque, up to the some number of most recent entries.

Tuple Fields

0: VecDeque<T>

Implementations

Source

impl<T, const N: usize> HistoricalList<T, N>
where T: Timestamped + Clone,

pub fn new() -> HistoricalList<T, N>

pub fn add(&mut self, historical_data: T)

Add a new entry, purging the oldest if at capacity. Entry must be newer than the most recent existing entry.

pub fn get_recent(&self, earliest_time: MonotonicInstant) -> Vec<T>

Retrieve list of entries with a time more recent than earliest_time, sorted from oldest to newest. May be empty.

pub fn get_before(&self, latest_time: MonotonicInstant) -> Vec<T>

Retrieve list of entries with a time before than latest_time, sorted from oldest to newest. May be empty.

pub fn get_between( &self, earliest_time: MonotonicInstant, latest_time: MonotonicInstant, ) -> Vec<T>

Retrieve list of entries inclusively between latest_time and earliest_time, sorted from oldest to newest. May be empty.